use leptos::*;
// use leptos_meta::*;
use leptos_router::*;

use crate::app::components::svgs::HamburgerSvg;

#[component]
fn Navbar() -> impl IntoView {
    view! {
        <div class="navbar bg-base-100">
            <div class="navbar-start">
                <div class="dropdown">
                    <div tabindex="0" role="button" class="btn btn-ghost btn-circle">
                        <HamburgerSvg/>
                    </div>
                    <ul
                        tabindex="0"
                        class="p-2 mt-3 w-52 border-2 shadow menu menu-sm dropdown-content z-[1] bg-base-100 rounded-box border-base-200"
                    >
                        <li>
                            <a href="/chat">"Chat"</a>
                        </li>
                        <li>
                            <a href="/settings/backend">"Settings"</a>
                        </li>
                    </ul>
                </div>
            </div>
            <div class="navbar-center">
                <a class="text-xl btn btn-ghost">"LLama Forge RS🦙🔨🦀"</a>
            </div>

            <div class="navbar-end">
                <button class="btn btn-ghost btn-circle">
                    <img class="w-12 h-12" src="/logo.svg"/>
                </button>
            </div>
        </div>
    }
}

#[component]
fn Footer() -> impl IntoView {
    view! {
        <footer class="items-center p-2 footer bg-neutral text-neutral-content">
            <nav class="grid-flow-col gap-2 md:justify-self-end md:place-self-center">
                <a href="/about">"About"</a>
            </nav>
        </footer>
    }
}

#[component]
pub fn Main(children: Children) -> impl IntoView {
    view! {
        <div class="flex flex-col w-screen h-screen">
            <Navbar/>
            <div class="grid place-items-center p-4 grow">{children()}</div>
        // <Footer/>
        </div>
    }
}

#[component]
pub fn MainPage() -> impl IntoView {
    view! {
        <Main>
            <Outlet/>
        </Main>
    }
}
