use leptos::*;
use leptos_router::*;

use crate::app::{components::svgs::*, RefreshGen};

mod backend;
pub mod process;

use backend::SettingsForm;
use process::ProcessForm;

#[component]
fn TabButton(path: &'static str, label: &'static str) -> impl IntoView {
    let current_path = use_location().pathname;
    view! {
        <a role="tab" class="tab" class:tab-active=move || current_path.get() == path href=path>
            {label}
        </a>
    }
}

#[component]
fn TabCard(children: Children) -> impl IntoView {
    view! {
        <div class="rounded-none !rounded-b-lg !rounded-tr-lg overflow-y-scroll flex-col-reverse shadow-xl max-h-[85dvh] size-full bg-base-300 card">
            <div class="card-body">{children()}</div>
        </div>
    }
}

#[component]
fn BackendSettingsPage() -> impl IntoView {
    view! {
        <div class="flex justify-around">
            <div class="flex flex-col p-4 w-1/3">
                <ProcessForm/>
            </div>
            <div class="flex flex-col p-4 w-2/3">
                <SettingsForm/>
            </div>
        </div>
    }
}

#[component]
fn ModelSettingsPage() -> impl IntoView {
    view! {
        <div>
            <p>"modellist here"</p>
            <p>"TODO"</p>
        </div>
    }
}

#[component]
fn SettingsPage() -> impl IntoView {
    let gen = use_context::<RwSignal<RefreshGen>>().expect("to have found the setter provided");

    let increment_gen = move |_ev| {
        gen.update(|gen| *gen = RefreshGen(gen.0 + 1));
    };

    view! {
        <div class="flex flex-col size-full">
            <div class="flex justify-between">
                <div
                    role="tablist"
                    class="shadow-xl border-b-2 border-base-200 bg-base-300 rounded-none !rounded-t-lg shrink tabs tabs-boxed"
                >
                    <TabButton path="/settings/backend" label="Backend"/>
                    <TabButton path="/settings/model" label="Model"/>
                </div>
                <div class="shadow-xl border-b-2 border-base-200 bg-base-300 rounded-none !rounded-t-lg shrink tabs tabs-boxed">
                    <button class="btn btn-sm" on:click=increment_gen>
                        <RefreshSvg/>
                    </button>
                </div>
            </div>
            <div class="grow">
                <TabCard>
                    <Outlet/>
                </TabCard>
            </div>
        </div>
    }
}

#[component(transparent)]
pub fn SettingsRoutes() -> impl IntoView {
    view! {
        <Route path="/settings" view=SettingsPage>
            <Route path="/backend" view=BackendSettingsPage/>
            <Route path="/model" view=ModelSettingsPage/>
        </Route>
    }
}
